@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: imp/lib/Folder.php,v 1.53.2.14 2003/06/14 14:16:32 chuck Exp $
+ * $Horde: imp/lib/Folder.php,v 1.53.2.16 2003/11/27 22:38:12 jan Exp $
  *
  * Copyright 2000-2003 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 2000-2003 Jon Parise <jon@csh.rit.edu>
@@ -15,7 +15,7 @@
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@csh.rit.edu>
- * @version $Revision: 1.53.2.14 $
+ * @version $Revision: 1.53.2.16 $
  * @since   IMP 2.3
  * @package imp
  */
@@ -266,7 +266,7 @@ class IMP_Folder {
         foreach ($folder_array as $folder) {
             if (!imap_deletemailbox($stream, $server . $folder)) {
                 Horde::raiseMessage(sprintf(_("The folder \"%s\" was not deleted. This is what the server said"), IMP::displayFolder($folder)) .
-                                    imap_last_error(), HORDE_ERROR);
+                                    ': ' . imap_last_error(), HORDE_ERROR);
                 $return_value = false;
             } else {
                 if ($subscribe && in_array($server . $folder, $subscribed_folders) &&
@@ -312,7 +312,7 @@ class IMP_Folder {
         /* Attempt to create the mailbox */
         if (!imap_createmailbox($stream, IMP::serverString() . $folder)) {
             Horde::raiseMessage(sprintf(_("The folder \"%s\" was not created. This is what the server said"), IMP::displayFolder($folder)) .
-                            imap_last_error(), HORDE_ERROR);
+                            ': ' . imap_last_error(), HORDE_ERROR);
             return false;
         }
 
@@ -378,7 +378,7 @@ class IMP_Folder {
             return true;
         } else {
             Horde::raiseMessage(sprintf(_("Renaming \"%s\" to \"%s\" failed. This is what the server said"), IMP::displayFolder($old), IMP::displayFolder($new)) .
-                                imap_last_error(), HORDE_ERROR);
+                                ': ' . imap_last_error(), HORDE_ERROR);
             return false;
         }
     }
@@ -402,7 +402,7 @@ class IMP_Folder {
                 if ($folder != ' ') {
                     if (!imap_subscribe($stream, IMP::serverString() . $folder)) {
                         Horde::raiseMessage(sprintf(_("You were not subscribed to \"%s\". Here is what the server said"), IMP::displayFolder($folder)) .
-                                            imap_last_error(), HORDE_ERROR);
+                                            ': ' . imap_last_error(), HORDE_ERROR);
                         $return_value = false;
                     } else {
                         Horde::raiseMessage(sprintf(_("You were successfully subscribed to \"%s\""), IMP::displayFolder($folder)), HORDE_SUCCESS);
@@ -436,7 +436,7 @@ class IMP_Folder {
                 if ($folder != ' ') {
                     if (!imap_unsubscribe($stream, IMP::serverString() . $folder)) {
                         Horde::raiseMessage(sprintf(_("You were not unsubscribed from \"%s\". Here is what the server said"), IMP::displayFolder($folder)) .
-                                        imap_last_error(), HORDE_ERROR);
+                                        ': ' . imap_last_error(), HORDE_ERROR);
                         $return_value = false;
                     } else {
                         Horde::raiseMessage(sprintf(_("You were successfully unsubscribed from \"%s\""), IMP::displayFolder($folder)), HORDE_SUCCESS);
@@ -481,7 +481,9 @@ class IMP_Folder {
                         }
                     }
 
-                    $date = date('D M j H:i:s Y', $h->udate);
+                    /* We need this long command since some MUAs (e.g. pine)
+                       require a space in front of single digit days. */
+                    $date = sprintf('%s %2s %s', date('D M', $h->udate), date('j', $h->udate), date('H:i:s Y', $h->udate));
                     $body .= 'From ' . $from . ' ' . $date . "\n";
                     $body .= imap_fetchheader($stream, $i, FT_PREFETCHTEXT);
                     $body .= imap_body($stream, $i) . "\n";
