@@ -5,7 +5,7 @@ require_once IMP_BASE . '/lib/constants.php';
 /**
  * IMP Base Class.
  *
- * $Horde: imp/lib/IMP.php,v 1.198.2.58 2003/08/21 01:54:07 chuck Exp $
+ * $Horde: imp/lib/IMP.php,v 1.198.2.64 2004/07/24 18:24:40 chuck Exp $
  *
  * Copyright 1999-2003 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
@@ -15,7 +15,7 @@ require_once IMP_BASE . '/lib/constants.php';
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.198.2.58 $
+ * @version $Revision: 1.198.2.64 $
  * @since   IMP 2.3.5
  * @package imp
  */
@@ -128,6 +128,12 @@ class IMP {
             $_SESSION['imp']['base_protocol'] = $_SESSION['imp']['protocol'];
         }
 
+        if (Horde::getFormData('url')) {
+            $_SESSION['imp']['direct_access'] = false;
+        } else {
+            $_SESSION['imp']['direct_access'] = true;
+        }
+
         $_SESSION['imp']['mailbox'] = '';
         if (IMP::authenticate(OP_HALFOPEN) === true) {
             if ($registry->getMethod('auth/login') == 'imp') {
@@ -1037,7 +1043,7 @@ class IMP {
         $row = '<tr valign="middle"><td><img src="' . $icon . '" height="16" width="16" border="0" alt="" /></td>';
 
         // number column
-        $row .= '<td>' . (!empty($mime->imap_id) ? $mime->imap_id : '&nbsp;') . '</td>';
+        $row .= '<td>' . (!empty($mime->imap_id) ? htmlspecialchars($mime->imap_id) : '&nbsp;') . '</td>';
 
         // name/text part column
         $row .= '<td>';
@@ -1049,8 +1055,8 @@ class IMP {
             $row .= '</td>';
         }
 
-        $row .= '<td>' . $mime->TYPE . '/' . $mime->subtype . '</td>';
-        $row .= '<td>' . $mime->size . ' KB</td>';
+        $row .= '<td>' . htmlspecialchars($mime_type) . '</td>';
+        $row .= '<td>' . htmlspecialchars($mime->size) . ' KB</td>';
 
         // download column
         if (!empty($mime->viewer->conf['no_download'])) {
@@ -1092,7 +1098,7 @@ class IMP {
                 if (!empty($line)) {
                     list($key, $val) = explode(':', $line, 2);
                     $val = strtr($val, ':', '_');
-                    $headers[$key] = trim($val);
+                    $headers[trim($key)] = trim($val);
                 }
             }
         }
@@ -1259,9 +1265,11 @@ class IMP {
         /* First try iconv with transliteration. */
         if (extension_loaded('iconv')) {
             ini_set('track_errors', 1);
-            $output = @iconv($charset, 'UTF7-IMAP', $input);
+            $output = @iconv($charset, 'UTF7-IMAP', $input . 'a');
             if (isset($php_errormsg)) {
                 $output = false;
+            } else {
+                $output = substr($output, 0, -1);
             }
             ini_restore('track_errors');
         }
@@ -1347,6 +1355,11 @@ class IMP {
      */
     function _rfc822Encode($str, $filter = '')
     {
+        // Strip double quotes if they are around the string already.
+        if (substr($str, 0, 1) == '"' && substr($str, -1) == '"') {
+            $str = substr($str, 1, -1);
+        }
+
         $filter .= "()<>@,;:\\\"[]\1\2\3\4\5\6\7\10\11\12\13\14\15\16\17\20\21\22\23\24\25\26\27\30\31\32\33\34\35\36\37\177";
 
         if (strcspn($str, $filter) != strlen($str)) {
