@@ -1,5 +1,5 @@
 <?php
-// $Horde: imp/lib/Message.php,v 1.32.2.12 2003/03/12 17:09:10 slusarz Exp $
+// $Horde: imp/lib/Message.php,v 1.32.2.13 2003/11/16 11:44:58 jan Exp $
 
 /**
  * The IMP_Message:: class contains all functions related to handling
@@ -11,7 +11,7 @@
  *
  * @author  Chris Hyde <chris@jeks.net>
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.32.2.12 $
+ * @version $Revision: 1.32.2.13 $
  * @since   IMP 2.3
  * @package imp
  */
@@ -136,7 +136,7 @@ class IMP_Message {
                     if ($msg_list != '') {
                         if (!imap_mail_copy($imp['stream'], $msg_list, $targetMbox, $imap_flags)) {
                             Horde::raiseMessage(sprintf($message, IMP::displayFolder($targetMbox)) .
-                                                ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                                ': ' . imap_last_error(), HORDE_ERROR);
                             $return_value = false;
                         }
                         if ($prefs->getValue('use_trash') && $action == MOVE_MESSAGES)
@@ -153,7 +153,7 @@ class IMP_Message {
             if ($msg_list != '') {
                 if (!imap_mail_copy($imp['stream'], $msg_list, $targetMbox, $imap_flags)) {
                     Horde::raiseMessage(sprintf($message, IMP::displayFolder($targetMbox)) .
-                                        ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                        ': ' . imap_last_error(), HORDE_ERROR);
                     $return_value = false;
                 }
                 if ($prefs->getValue('use_trash') && $action == MOVE_MESSAGES) {
@@ -164,7 +164,7 @@ class IMP_Message {
             $msg_list = implode(',', $msgs);
             if (!imap_mail_copy($imp['stream'], $msg_list, $targetMbox, $imap_flags)) {
                 Horde::raiseMessage(sprintf($message, IMP::displayFolder($targetMbox)) .
-                                    ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                    ': ' . imap_last_error(), HORDE_ERROR);
                 $return_value = false;
             }
             if ($prefs->getValue('use_trash') && $action == MOVE_MESSAGES) {
@@ -217,13 +217,13 @@ class IMP_Message {
                         }
                         if (!imap_mail_copy($imp['stream'], $msg, $trash_folder, CP_UID | CP_MOVE)) {
                             Horde::raiseMessage(sprintf(_("There was an error moving messages to the trash. This is what the server said")) .
-                                                ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                                ': ' . imap_last_error(), HORDE_ERROR);
                             $return_value = false;
                         }
                     } else {
                         if (!imap_delete($imp['stream'], $msg, FT_UID)) {
                             Horde::raiseMessage(sprintf(_("There was an error deleting messages from the folder \"%s\". This is what the server said"),
-                                                        IMP::displayFolder($msg_folder)) . ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                                        IMP::displayFolder($msg_folder)) . ': ' . imap_last_error(), HORDE_ERROR);
                             $return_value = false;
                         }
                     }
@@ -247,13 +247,13 @@ class IMP_Message {
                     }
                     if (!@imap_mail_copy($imp['stream'], $msg_list, $trash_folder, CP_UID | CP_MOVE)) {
                         Horde::raiseMessage(sprintf(_("There was an error moving messages to the trash. This is what the server said")) .
-                                            ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                            ': ' . imap_last_error(), HORDE_ERROR);
                         $return_value = false;
                     }
                 } else {
                     if (!@imap_delete($imp['stream'], $msg_list, FT_UID)) {
                         Horde::raiseMessage(sprintf(_("There was an error deleting messages. This is what the server said")) .
-                                            ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                            ': ' . imap_last_error(), HORDE_ERROR);
                         $return_value = false;
                     }
                 }
@@ -261,7 +261,7 @@ class IMP_Message {
             } else {
                 if (!@imap_delete($imp['stream'], $msg_list, FT_UID)) {
                     Horde::raiseMessage(sprintf(_("There was an error deleting messages. This is what the server said")) .
-                                        ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                        ': ' . imap_last_error(), HORDE_ERROR);
                     $return_value = false;
                 }
                 if ($imp['base_protocol'] == 'pop3') {
@@ -298,7 +298,7 @@ class IMP_Message {
                 }
                 if ($imp['stream'] && !imap_undelete($imp['stream'], $msg_num, FT_UID)) {
                     Horde::raiseMessage(sprintf(_("There was an error deleting messages in the folder \"%s\". This is what the server said"),
-                                                IMP::displayFolder($msg_folder)) . ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                                IMP::displayFolder($msg_folder)) . ': ' . imap_last_error(), HORDE_ERROR);
                     $return_value = false;
                 }
                 $current_folder = $msg_folder;
@@ -311,7 +311,7 @@ class IMP_Message {
             }
             if (!imap_undelete($imp['stream'], $message_list, FT_UID)) {
                 Horde::raiseMessage(sprintf(_("There was an error undeleting messages. This is what the server said")) .
-                                    ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                    ': ' . imap_last_error(), HORDE_ERROR);
                 $return_value = false;
             }
         }
@@ -360,7 +360,7 @@ class IMP_Message {
                     if ($msg_list != '') {
                         if (!$function($imp['stream'], $msg_list, $flag, ST_UID)) {
                             Horde::raiseMessage(sprintf(_("There was an error flagging messages in the folder \"%s\". This is what the server said"),
-                                                        IMP::displayFolder($current_folder)) . ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                                        IMP::displayFolder($current_folder)) . ': ' . imap_last_error(), HORDE_ERROR);
                             $return_value = false;
                         }
                     }
@@ -375,7 +375,7 @@ class IMP_Message {
             if ($msg_list != '') {
                 if (!$function($imp['stream'], $msg_list, $flag, ST_UID)) {
                     Horde::raiseMessage(sprintf(_("There was an error flagging messages in the folder \"%s\". This is what the server said"),
-                                                IMP::displayFolder($current_folder)) . ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                                IMP::displayFolder($current_folder)) . ': ' . imap_last_error(), HORDE_ERROR);
                     $return_value = false;
                 }
             }
@@ -383,7 +383,7 @@ class IMP_Message {
             $msg_list = implode(',', $indices);
             if (!$function($imp['stream'], $msg_list, $flag, ST_UID)) {
                 Horde::raiseMessage(sprintf(_("There was an error flagging messages. This is what the server said")) .
-                                    ': <i>' . imap_last_error() . '</i>', HORDE_ERROR);
+                                    ': ' . imap_last_error(), HORDE_ERROR);
                 $return_value = false;
             }
         }
