@@ -1,9 +1,9 @@
 <?php
 /*
- * $Horde: imp/message.php,v 2.257.2.39 2003/01/16 22:29:02 jan Exp $
+ * $Horde: imp/message.php,v 2.257.2.44 2004/03/26 22:43:24 jan Exp $
  *
- * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2003 Jon Parise <jon@horde.org>
+ * Copyright 1999-2004 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2004 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -21,6 +21,13 @@ require_once HORDE_BASE . '/config/mime_mapping.php';
 require_once IMP_BASE . '/config/mime_drivers.php';
 require_once IMP_BASE . '/lib/Identity/IMP.php';
 
+if (empty($notification)) {
+    require_once HORDE_BASE . '/lib/Notification.php';
+    $notification = &Notification::singleton();
+    $notification->attach('status');
+}
+$show_whitelist = $registry->hasMethod('filter/whitelistFrom');
+
 /**
  * Builds a string containing a list of addresses.  Each address is a link
  * to the compose function.
@@ -65,7 +72,7 @@ function buildAddressLinks($array, $icon)
 
         /* Get full address ($addr) and the trimmed, bare address ($inner). */
         $addr = IMP::addrObject2String($ob, 'undisclosed-recipients@');
-        $inner = Mime::trimEmailAddress(imap_rfc822_write_address($ob->mailbox,
+        $inner = Mime::trimEmailAddress(IMP::rfc822WriteAddress($ob->mailbox,
                     $ob->host, ''));
 
         /* Separate multiple addresses with a comma. */
@@ -282,16 +289,41 @@ switch ($actionID) {
      break;
 
  case IMP_BLACKLIST:
-     $filters = @unserialize($prefs->getValue('filters'));
-     $h = @imap_header($imp['stream'], imap_msgno($imp['stream'], $index));
-     if (isset($h->from[0])) {
-         $ob = $h->from[0];
-         $addr = Mime::trimEmailAddress(imap_rfc822_write_address($ob->mailbox, $ob->host, ''));
-         $filters[] = array('fields' => array('from'), 'text' => trim($addr), 'action' => 'delete');
+     if ($registry->hasMethod('filter/blacklistFrom')) {
+         $addresses = array();
+         $h = @imap_header($imp['stream'], imap_msgno($imp['stream'], $index));
+         if (isset($h->from[0])) {
+             $ob = $h->from[0];
+             $addr = Mime::trimEmailAddress(IMP::rfc822WriteAddress($ob->mailbox, $ob->host, ''));
+             $addresses[] = trim($addr);
+             $registry->call('filter/blacklistFrom', array($addresses));
+         }
+     } else {
+         $filters = @unserialize($prefs->getValue('filters'));
+         $h = @imap_header($imp['stream'], imap_msgno($imp['stream'], $index));
+         if (isset($h->from[0])) {
+             $ob = $h->from[0];
+             $addr = Mime::trimEmailAddress(IMP::rfc822WriteAddress($ob->mailbox, $ob->host, ''));
+             $filters[] = array('fields' => array('from'), 'text' => trim($addr), 'action' => 'delete');
+         }
+         $prefs->setValue('filters', serialize($filters));
+         $prefs->store();
+         header('Location: ' . Horde::applicationUrl('filters.php'));
+         exit;
+     }
+     break;
+
+ case IMP_WHITELIST:
+     if ($show_whitelist) {
+         $addresses = array();
+         $h = @imap_header($imp['stream'], imap_msgno($imp['stream'], $index));
+         if (isset($h->from[0])) {
+             $ob = $h->from[0];
+             $addr = Mime::trimEmailAddress(IMP::rfc822WriteAddress($ob->mailbox, $ob->host, ''));
+             $addresses[] = trim($addr);
+             $registry->call('filter/whitelistFrom', array($addresses));
+         }
      }
-     $prefs->setValue('filters', serialize($filters));
-     $prefs->store();
-     header('Location: ' . Horde::applicationUrl('filters.php'));
      break;
 
  case PRINT_MESSAGE:
@@ -404,35 +436,43 @@ switch ($actionID) {
      }
 
      /* Fetch the raw message contents (headers and complete body). */
-     $raw_msg = imap_fetchheader($imp['stream'], $index, FT_UID) . "\n" .
-         imap_body($imp['stream'], $index, FT_UID);
+     $raw_msg = imap_fetchheader($imp['stream'], $index, FT_UID) . "\n" . imap_body($imp['stream'], $index, FT_UID);
 
-     /* Build the MIME structure. */
-     include_once HORDE_BASE . '/lib/MIME/Message.php';
-     include_once HORDE_BASE . '/lib/MIME/Part.php';
+     /* If a spam reporting program has been provided, use it. */
+     if (!empty($conf['spam']['program'])) {
+         /* Use a pipe to write the message contents. This should be secure. */
+         $pipe = popen($conf['spam']['program'], 'w');
+         fwrite($pipe, $raw_msg);
+         pclose($pipe);
 
-     $mime = new MIME_Message($raw_msg);
-     $body = new MIME_Part('text/plain', $raw_msg);
-     $mime->addPart($body);
-     $msg = $mime->toString();
+         Horde::raiseMessage(_("This message has been reported as spam."), HORDE_MESSAGE);
+     }
 
-     $headers['Message-ID'] = '<' . uniqid(time() . '.') . '@' . $_SERVER['SERVER_NAME'] . '>';
-     $headers['Date'] = date('r');
-     $headers['To'] = $conf['spam']['email'];
-     $headers['From'] = $user_identity->getFromLine();
-     $recipients = $conf['spam']['email'];
-     $headers['Subject'] = _("Spam Report from") . ' ' . $imp['user'];
-     $headers = $mime->header($headers);
-     IMP::addSiteHeaders($headers);
+     /* If a spam reporting email address has been provided, use it. */
+     if (!empty($conf['spam']['email'])) {
+         include_once HORDE_BASE . '/lib/MIME/Message.php';
+         include_once HORDE_BASE . '/lib/MIME/Part.php';
+         include_once 'Mail.php';
 
-     include_once 'Mail.php';
-     if (!empty($imp['smtphost'])) {
-         $conf['mailer']['params']['host'] = $imp['smtphost'];
+         /* Build the MIME structure. */
+         $mime = &new MIME_Message();
+         $mime->addPart(new MIME_Part('text/plain', $raw_msg));
+
+         $header['Message-ID'] = '<' . uniqid(time() . '.') . '@' . $_SERVER['SERVER_NAME'] . '>';
+         $header['Date'] = date('r');
+         $header['To'] = $conf['spam']['email'];
+         $header['From'] = $user_identity->getFromLine();
+         $header['Subject'] = _("Spam Report from") . ' ' . $imp['user'];
+         $header = $mime->header($header);
+         IMP::addSiteHeaders($header);
+
+         /* Send the message. */
+         $mailer = &Mail::factory($conf['mailer']['type'], IMP::prepareMailerParams());
+         $mailer->send($conf['spam']['email'], $mime->encode($header), $mime->toString());
+
+         Horde::raiseMessage(_("This message has been reported as spam to your system administrator."), HORDE_MESSAGE);
      }
-     $mailer = &Mail::factory($conf['mailer']['type'], $conf['mailer']['params']);
-     $mailer->send($recipients, $headers, $msg);
 
-     Horde::raiseMessage(_("This message has been reported as spam to your system administrator."), HORDE_MESSAGE);
      break;
 
  case ADD_ADDRESS:
@@ -558,6 +598,7 @@ if (!$printer_friendly) {
     include IMP_BASE . '/menu.php';
     include IMP_BASE . '/status.php';
 }
+$notification->notify();
 
 if (!empty($conf['hooks']['quota']) && function_exists($conf['hooks']['quota'])) {
     echo call_user_func($conf['hooks']['quota'], $imp);
@@ -588,7 +629,7 @@ if (($array_index + 1) != count($sorted)) {
     $form_target = 'message.php';
     $form_ident  = 'index';
     $form_method = 'get';
-    $form_link = "$form_target?$form_ident=$form_index&start=$msgindex&thismailbox=" . $imp['thismailbox'];
+    $form_link = "$form_target?$form_ident=$form_index&start=$msgindex&thismailbox=" . urlencode($imp['thismailbox']);
 
 } else {
     $form_target = 'mailbox.php';
