@@ -1,9 +1,9 @@
 <?php
 /*
- * $Horde: imp/redirect.php,v 1.23.2.18 2003/06/14 15:13:38 chuck Exp $
+ * $Horde: imp/redirect.php,v 1.23.2.20 2004/03/26 22:43:24 jan Exp $
  *
- * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2003 Jon Parise <jon@horde.org>
+ * Copyright 1999-2004 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2004 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -95,12 +95,6 @@ if (!is_null($imapuser) && !is_null($pass)) {
             $_SESSION['horde_language'] = $horde_language;
         }
 
-        if (Horde::getFormData('url')) {
-            $imp['direct_access'] = false;
-        } else {
-            $imp['direct_access'] = true;
-        }
-
         IMP::loginTasks();
 
         if (Horde::getFormData('url')) {
